@@ -31,6 +31,10 @@
 #'   \item{method}{estimation method used}
 #'   \item{itemtype}{a vector of item types for each respective item (e.g., 'graded', '2PL', etc)}
 #'   \item{itemnames}{a vector of item names from the input data}
+#'   \item{factorNames}{a vector of factor names from the model definition}
+#'   \item{rowID}{an integer vector indicating all valid row numbers used in the model estimation
+#'    (when all cases are used this will be \code{1:nrow(data)}). Mostly useful when the option
+#'     \code{technical = list(removeEmptyRows = TRUE)} was passed}
 #'   \item{data}{raw input data of item responses}
 #'   \item{covdata}{raw input data of data used as covariates}
 #'   \item{tabdatalong}{similar to \code{tabdata}, however the responses have been transformed into
@@ -143,6 +147,8 @@ extract.mirt <- function(x, what){
                   groupNames = x@Data$groupNames,
                   time = x@time,
                   survey.weights = x@Internals$survey.weights,
+                  rowID = x@Data$rowID,
+                  factorNames=x@Model$factorNames,
                   # undocumented
                   factorNames = x@Model$factorNames,
                   parprior = x@Model$parprior,
