@@ -43,7 +43,9 @@
 #' @param data a \code{matrix} or \code{data.frame} that consists of
 #'   numerically ordered data, with missing data coded as \code{NA}
 #' @param covdata a \code{data.frame} that consists of the \code{nrow(data)} by \code{K}
-#'   'person level' fixed and random predictors
+#'   'person level' fixed and random predictors. If missing data are present in this object
+#'   then the observations from \code{covdata} and \code{data} will be removed row-wise
+#'   via the \code{rowSums(is.na(covdata)) > 0}
 #' @param model an object returned from, or a string to be passed to, \code{mirt.model()}
 #'   to declare how the IRT model is to be estimated. See \code{\link{mirt.model}} for
 #'   more details
@@ -390,6 +392,9 @@ mixedmirt <- function(data, covdata = NULL, model, fixed = ~ 1, random = NULL, i
         stop('number of rows in covdata do not match number of rows in data', call.=FALSE)
     dropcases <- which(rowSums(is.na(covdata)) != 0)
     if(length(dropcases) > 0L){
+        if(is.null(technical$warn) || technical$warn)
+            warning("Missing values in covdata not permitted. Removing all observations row-wise
+                     when rowSums(is.na(covdata)) > 0")
         data <- data[-dropcases, ]
         covdata <- covdata[-dropcases, ,drop=FALSE]
     }
