@@ -21,15 +21,15 @@ test_that('DCIRT', {
     fs1 <- fscores(mod)
     fs2 <- fscores(mod, use_dentype_estimate = TRUE)
     expect_equal(fs1[1:3], c(-1.5345966, -0.8099821, -1.2411356), tolerance=1e-4)
-    expect_equal(fs2[1:3], c(-1.3326057, -0.9158906, -1.0891405), tolerance=1e-4)
+    expect_equal(fs2[1:3], c(-1.3336196, -0.9165531, -1.0881438), tolerance=1e-4)
     fs1 <- fscores(mod, method = 'EAPsum')
     fs2 <- fscores(mod, method = 'EAPsum', use_dentype_estimate = TRUE)
     expect_equal(fs1[1:3], c(-1.4499389, -0.8284078, -1.4499389), tolerance=1e-4)
-    expect_equal(fs2[1:3], c(-1.2365365, -0.9185588, -1.2365365), tolerance=1e-4)
+    expect_equal(fs2[1:3], c(-1.236668, -0.919067, -1.236668), tolerance=1e-4)
     resid <- residuals(mod, verbose=FALSE)
     resid2 <- residuals(mod, use_dentype_estimate=TRUE, verbose=FALSE)
-    expect_equal(unname(resid[2:4,1]), c(3.4535477, -5.8701794, -0.1191689), tolerance=1e-4)
-    expect_equal(unname(resid2[2:4,1]), c(2.1052352, -1.9251709, -0.1225053), tolerance=1e-4)
+    expect_equal(unname(resid[2:4,1]), c(3.454542, 5.869551, 0.119278), tolerance=1e-4)
+    expect_equal(unname(resid2[2:4,1]), c(2.1035571, 1.9256263, 0.1226077), tolerance=1e-4)
 
     pp <- plot(mod, type = 'empiricalhist')
     expect_is(pp, 'trellis')
@@ -162,8 +162,8 @@ test_that('DCIRT-MG', {
     mod_scalar0 <- multipleGroup(dat, 1, group = group, verbose=FALSE, dentype='Davidian-6',
                                 invariance=colnames(dat)[1:5])
     # coef(mod_scalar0, simplify=TRUE)
-    expect_equal(extract.mirt(mod_scalar0, 'logLik'), -23962.58, tolerance=1e-4)
-    expect_equal(extract.mirt(mod_scalar0, 'df'), 33554329)
+    expect_equal(extract.mirt(mod_scalar0, 'logLik'), -23968.56, tolerance=1e-4)
+    expect_equal(extract.mirt(mod_scalar0, 'df'), 67108760)
     # plot(mod_scalar0)
     pp <- plot(mod_scalar0, type = 'Davidian')
     expect_is(pp, 'trellis')
@@ -185,7 +185,7 @@ test_that('DCIRT-MG', {
     mod_scalarEHW <- multipleGroup(dat, 1, group = group, verbose=FALSE, dentype='EHW',
                                 invariance=c(colnames(dat)[1:10], 'free_var','free_means'))
     # plot(mod_scalarEHW)
-    expect_equal(extract.mirt(mod_scalarEHW, 'df'), 33554113)
+    expect_equal(extract.mirt(mod_scalarEHW, 'df'), 67108544)
     expect_equal(extract.mirt(mod_scalarEHW, 'logLik'), -23877.63, tolerance=1e-4)
     cfs <- as.vector(unname(coef(mod_scalarEHW)$G2$GroupPars))
     expect_equal(cfs, c(0.5093032, 0.6000460), tolerance=1e-4)
